Function cairo_lang_test_plugin::test_assert_suite
source · pub fn test_assert_suite() -> PluginSuiteExpand description
The suite of plugins that implements assert macros for tests.
pub fn test_assert_suite() -> PluginSuiteThe suite of plugins that implements assert macros for tests.