Struct cairo_lang_test_plugin::TestCompilation
source · pub struct TestCompilation {
pub sierra_program: ProgramArtifact,
pub metadata: TestCompilationMetadata,
}Expand description
Encapsulation of all data required to execute tests. This includes the source code compiled to a Sierra program and all cairo-test specific data extracted from it. This can be stored on the filesystem and shared externally.
Fields
sierra_program: ProgramArtifactmetadata: TestCompilationMetadataTrait Implementations
sourceimpl Clone for TestCompilation
impl Clone for TestCompilation
sourcefn clone(&self) -> TestCompilation
fn clone(&self) -> TestCompilation
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for TestCompilation
impl Debug for TestCompilation
sourceimpl<'de> Deserialize<'de> for TestCompilation
impl<'de> Deserialize<'de> for TestCompilation
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for TestCompilation
impl PartialEq for TestCompilation
sourceimpl Serialize for TestCompilation
impl Serialize for TestCompilation
impl StructuralPartialEq for TestCompilation