Module test_config

Module test_config 

Structs

TestConfig
The configuration for running a single test.

Enums

PanicExpectation
Expectation for a panic case.
TestExpectation
Expectation for a result of a test.

Functions

try_extract_test_config
Extracts the configuration of a tests from attributes, or returns the diagnostics if the attributes are set illegally.