Module cairo_lang_test_plugin::test_config
source · Structs
- The configuration for running a single test.
Enums
- Expectation for a panic case.
- Expectation for a result of a test.
Functions
- Extracts the configuration of a tests from attributes, or returns the diagnostics if the attributes are set illegally.